# Noteworthy

LLM-related tools for command-line use.


## Scope

- pdf2md: convert pdf (as image) to markdown
- pdf2latex: convert pdf (as image) to latex
- review: Act as a reviewer for a paper (TBD)
- editor: Act as an editor for a paper (TBD)
- proofread: Act as a proofreader for a paper (TBD)


## Components

- noteworthy/cli        [apply stdio to tools]
- noteworthy/pipeline   [applied templates, use trag/template]
- noteworthy/util       [local utils]

## Install

```bash
$ pip install nwy
```
